// lxgTelescopeFileImplementation.cpp: implementation of the lxgTelescopeFileImplementation class.
//
//////////////////////////////////////////////////////////////////////

#include "stdafx.h"
#include "lxgTelescopeFile.h"
#include "lxgTelescopeFileImplementation.h"
#include "SetupDialog.h"
#include <fstream>
using namespace std;

const char* telescope_name = "lxgTelescopeFile";
static CString path="";
static bool csv_logfile=false;

ofstream* xdat = NULL;
ofstream* ydat = NULL;
ofstream* csv  = NULL;

extern "C" {

int lxgTelescopeInitialise()
{
   AFX_MANAGE_STATE(AfxGetStaticModuleState());

   csv_logfile = (AfxGetApp()->GetProfileInt("Settings","CSV_logfile",0) == 1);

   // just get the path to where the files shall be written
   path = AfxGetApp()->GetProfileString("Settings","Path",NULL);
   if(path.GetLength() == 0)return 0; // failed
   return 1; // ok
}

int lxgTelescopeName(char* xtelescope_name)
{
   strcpy(xtelescope_name,telescope_name);
   return 1;
}


int lxgTelescopeSetup()
{
   AFX_MANAGE_STATE(AfxGetStaticModuleState());

   // fire up a dialog for selecting the path
   CSetupDialog dialog;
   dialog.m_path    = path;
   dialog.m_logfile = csv_logfile;
   if(dialog.DoModal()){
      path = dialog.m_path;
      csv_logfile =  (dialog.m_logfile==TRUE);

      AfxGetApp()->WriteProfileString("Settings","Path",path);
      AfxGetApp()->WriteProfileInt("Settings","CSV_logfile",(csv_logfile)? 1 : 0);
      return 1;
   }
   return 0;
}


int lxgTelescopeStartGuide()
{
   lxgTelescopeStopGuide();

   CString xpath = path + '\\' + "X.DAT";
   CString ypath = path + '\\' + "Y.DAT";
   xdat = new ofstream(xpath);
   ydat = new ofstream(ypath);

   if(csv_logfile) {

      time_t time_sec;
      time(&time_sec);
      CTime timenow(time_sec);
      CString filename = timenow.Format("lxgTelescopeFile_%Y%m%d_%H%M%S.csv");
      CString csvname = path + '\\' + filename;
      csv = new ofstream(csvname);
      (*csv) << "Time [s], dx [arcsec], dy [arcsec]" << endl;
   }

   if(xdat && ydat)return 1;
   return 0;
}

int lxgTelescopeGuide(long timestamp, double dx, double dy)
{
   if(xdat && ydat) {


      double seconds=(double)timestamp/(double)CLOCKS_PER_SEC;

      CString xf,yf;
      xf.Format(" %8.2f  %8.2f",seconds,dx);
      yf.Format(" %8.2f  %8.2f",seconds,dy);

      // rewind x.dat and write new line
      xdat->seekp (0, ios::beg);
      (*xdat) << LPCSTR(xf) << endl;

      // rewind y.dat and write new line
      ydat->seekp (0, ios::beg);
      (*ydat) << LPCSTR(yf) << endl;

      if(csv) {
         (*csv) << seconds << ", " << dx <<  ", " << dy << endl;
      }

      return 1;
   }
   return 0;
}

int lxgTelescopeStopGuide()
{
   delete xdat; xdat = 0;
   delete ydat; ydat = 0;
   delete csv;  csv  = 0;
   return 1;
}



}